==> openpkg-registry-0.7.0.tar.gz: openpkg-registry-0.7.0/registry.pm <==
#!@l_prefix@/bin/perl
##
##  registry.pm - OpenPKG Registry Common Code Perl Module
##  Copyright (c) 2006-2006 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2006-2006 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

package registry;
use strict;

use Clone qw(clone);

#   program name, version and date
my $progname="registry.pm";
my $progvers="0.7.0";
my $progdate="07-Aug-2006";

#   get configuration file name
#
sub getcfgfilename ($)
{
    my ($prefix) = @_;
    my $cfgfile = "";
    $cfgfile = "$prefix/etc/openpkg-registry/registry.cfg" unless ($prefix =~ m/^@.*@$/);
    return $cfgfile;
}

#   get default configuration text
#
sub getdefcfgtxt ($)
{
    my ($prefix) = @_;
    my $txt = qq{
        ##
        ##  registry.cfg - OpenPKG Registry Configuration
        ##
        
        #   user identification
        #
        identification {
            mode constant; /* constant, naive, basicauth, ase */
            ase {
                server "http://my.example.com/ase";
            };
            default anonymous;
        };
        
        #   databases for registry and session
        #
        db {
            registry {
                businesscategories "$prefix/etc/openpkg-registry/businesscategories.dat";
                countrycodes       "$prefix/etc/openpkg-registry/countrycodes.dat";
                superuser {
                    username postgresql;
                    password postgresql;
                };
                username   registry;
                password   registry;
                tablespace registry;
                location   "$prefix/var/openpkg-registry/db";
                dumpfile   "$prefix/var/openpkg-registry/db.dump";
                database   registry;
                host       127.0.0.1;
                pg_dump    "$prefix/bin/pg_dump";
                psql       "$prefix/bin/psql";
            };
            session {
                dbfile "$prefix/var/openpkg-registry/ui/session.db";
            };
        };

        #   enable processing of additional data
        request {
            package 1;
        };

        #   profile
        profile {
            token {
                maxperuser 3;
                uienable 1;
                userenable 1;
                linkenable 1;
                assocenable 1;
                assocrequestpackagemandatory 1;
            };
            mandatories {
                fullname         1;
                organization     1;
                businesscategory 1;
                addresslabel     1;
                country          1;
                timezone         1;
                telephonenumber  1;
                mobilenumber     0;
            };
        };
        
        #   canvas integration
        #
        canvas {
            url ""; /* "http://my.example.com/canvas" */
            urlcache;
            mark_head "<!-- CANVAS: HEAD -->";
            mark_body "<!-- CANVAS: BODY -->";
        };
        
        #   entry page
        #
        page {
            default "main"; /* "", main, dropxml, login, association, logout */
            main q{
                <h3>Welcome to the OpenPKG Registry main entrance.</h3>
                The registry collects information about instances and packages.<br>
                <b>NOTICE:</b> Version 0.6 introduced uploading package information by default.<br>
                Read details in the manpage <code>openpkg&nbsp;man&nbsp;register</code><br>
                Find more information in the manpage under <code>--data</code> option and <code>OPENPKG_PREP</code> file.
                <p/>
                Use the following software to get the <code>openpkg register</code> command.
                <p/>
                <ul>
                    <li>OpenPKG CURRENT<br>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2-STABLE<br>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2-STABLE-20060622 SNAPSHOT<br>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2.5 RELEASE<br>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2.4, 2.3, 2.2, 2.1, 2.0 RELEASE<br>
                        <a href="http://www.openpkg.org/download/">Download</a> and install the CURRENT openpkg-registry package.</li>
                    <li>OpenPKG 1.x<br>
                        <i>unsupported</i></li>
                </ul>
            };
        };

        ##   status line
        #
        status {
            showuser 1;
            showversion 0;
            showsid 0;
        };

        ##   debugging
        #
        debug {
            ui 0;
        };
    };
    $txt =~ s/^\n//s;           # remove leading newline
    $txt =~ s/^[ ]{8}//mg;      # clear fixed-width indentation
    $txt =~ s/ *$//mg;          # remove trailing spaces
    $txt =~ s/^ *\n/\n/sg;      # wipe out whitespace-only lines
    $txt =~ s/\n{2,}/\n\n/sg;   # consolidate excessive newlines
    return $txt;
}

#   read configuration text file
#
sub readcfgtxtfile ($)
{
    my ($cfgfile) = @_;
    my $txt = '';
    if ($cfgfile) {
        my $io = new IO::File "<$cfgfile";
        die "cannot open \"$cfgfile\" for reading ($!)" if(not defined $io);
        $txt .= $_ while (<$io>);
        $io->close();
    }
    return $txt;
}

#   parse configuration text
#
sub parsecfgtxt ($)
{
    my ($text) = @_;
    my $parse = {};
    my $osspcfg = new OSSP::cfg::simple;
    $osspcfg->parse($text) || die "error parsing config file";
    $parse = $osspcfg->unpack(-index => '.*', -strip => '.*', -flatten => 1) || die "error unpacking config file";
    return $parse;
}

#   merge configuration
#
#   merges two hashes. First argument is a hash working as accumulator and the
#   second argument is the hash to be added to it. Either argument can be
#   empty.  A typical application is the accumulator being prefilled with
#   defaults and the adder comes with overrides. The function recursively
#   processes nested hashes. Values with dissimilar keys will be merged,
#   missing data on either side will be accumulated and identical keys on both
#   sides will be overwritten with the added data. Returns a new hash with
#   cloned data. The original accumulator and adder passed in remain untouched.
#   If the first element in an array is a hash it is assumed a pseudo-hash as
#   described in perlref(1) encountered and hash merging is attempted.
#
sub mergecfg ($$) {
    my ($acc, $add) = @_;
    $acc = clone($acc);
    $add = clone($add);
    foreach my $k (sort keys %{$add}) {
        if (    (ref($acc->{$k}) eq "HASH" || (ref($acc->{$k}) eq "ARRAY" and ref($acc->{$k}[0]) eq "HASH"))
            and (ref($add->{$k}) eq "HASH" || (ref($add->{$k}) eq "ARRAY" and ref($add->{$k}[0]) eq "HASH"))
           ) {
            $acc->{$k} = &mergecfg($acc->{$k}, $add->{$k});
        }
        else {
            $acc->{$k} = $add->{$k};
        }
    }
    return $acc;
}

1;

==> openpkg-registry-0.7.1.tar.gz: openpkg-registry-0.7.1/registry.pm <==
#!@l_prefix@/bin/perl
##
##  registry.pm - OpenPKG Registry Common Code Perl Module
##  Copyright (c) 2006-2006 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2006-2006 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

package registry;
use strict;

use Clone qw(clone);

#   program name, version and date
my $progname="registry.pm";
my $progvers="0.7.1";
my $progdate="08-Aug-2006";

#   get configuration file name
#
sub getcfgfilename ($)
{
    my ($prefix) = @_;
    my $cfgfile = "";
    $cfgfile = "$prefix/etc/openpkg-registry/registry.cfg" unless ($prefix =~ m/^@.*@$/);
    return $cfgfile;
}

#   get default configuration text
#
sub getdefcfgtxt ($)
{
    my ($prefix) = @_;
    my $txt = qq{
        ##
        ##  registry.cfg - OpenPKG Registry Configuration
        ##
        
        #   user identification
        #
        identification {
            mode constant; /* constant, naive, basicauth, ase */
            ase {
                server "http://my.example.com/ase";
            };
            default anonymous;
        };
        
        #   databases for registry and session
        #
        db {
            registry {
                businesscategories "$prefix/etc/openpkg-registry/businesscategories.dat";
                countrycodes       "$prefix/etc/openpkg-registry/countrycodes.dat";
                superuser {
                    username postgresql;
                    password postgresql;
                };
                username   registry;
                password   registry;
                tablespace registry;
                location   "$prefix/var/openpkg-registry/db";
                dumpfile   "$prefix/var/openpkg-registry/db.dump";
                database   registry;
                host       127.0.0.1;
                pg_dump    "$prefix/bin/pg_dump";
                psql       "$prefix/bin/psql";
            };
            session {
                dbfile "$prefix/var/openpkg-registry/ui/session.db";
            };
        };

        #   enable processing of additional data
        request {
            package 1;
        };

        #   profile
        profile {
            token {
                maxperuser 3;
                uienable 1;
                userenable 1;
                linkenable 1;
                assocenable 1;
                assocrequestpackagemandatory 1;
            };
            mandatories {
                fullname         1;
                organization     1;
                businesscategory 1;
                addresslabel     1;
                country          1;
                timezone         1;
                telephonenumber  1;
                mobilenumber     0;
            };
        };
        
        #   canvas integration
        #
        canvas {
            url ""; /* "http://my.example.com/canvas" */
            urlcache;
            mark_head "<!-- CANVAS: HEAD -->";
            mark_body "<!-- CANVAS: BODY -->";
        };
        
        #   entry page
        #
        page {
            default "main"; /* "", main, dropxml, login, association, logout */
            main q{
                <h3>Welcome to the OpenPKG Registry main entrance.</h3>
                The registry collects information about users, instances and packages.<br/>
                <b>NOTICE:</b> Version 0.6 introduced uploading package information by default.<br/>
                Read details in the manpage <code>openpkg&nbsp;man&nbsp;register</code><br/>
                Find more information in the manpage under <code>--data</code> option and <code>OPENPKG_PREP</code> file.
                <p/>
                Use the following software to get the <code>openpkg register</code> command.
                <p/>
                <ul>
                    <li>OpenPKG CURRENT<br/>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2-STABLE<br/>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2-STABLE-20060622 SNAPSHOT<br/>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2.5 RELEASE<br/>
                        <i>embedded in bootstrap</i></li>
                    <li>OpenPKG 2.4, 2.3, 2.2, 2.1, 2.0 RELEASE<br/>
                        <a href="http://www.openpkg.org/download/">Download</a> and install the CURRENT openpkg-registry package.</li>
                    <li>OpenPKG 1.x<br/>
                        <i>unsupported</i></li>
                </ul>
            };
        };

        ##   status line
        #
        status {
            showuser 1;
            showversion 0;
            showsid 0;
        };

        ##   debugging
        #
        debug {
            ui 0;
        };
    };
    $txt =~ s/^\n//s;           # remove leading newline
    $txt =~ s/^[ ]{8}//mg;      # clear fixed-width indentation
    $txt =~ s/ *$//mg;          # remove trailing spaces
    $txt =~ s/^ *\n/\n/sg;      # wipe out whitespace-only lines
    $txt =~ s/\n{2,}/\n\n/sg;   # consolidate excessive newlines
    return $txt;
}

#   read configuration text file
#
sub readcfgtxtfile ($)
{
    my ($cfgfile) = @_;
    my $txt = '';
    if ($cfgfile) {
        my $io = new IO::File "<$cfgfile";
        die "cannot open \"$cfgfile\" for reading ($!)" if(not defined $io);
        $txt .= $_ while (<$io>);
        $io->close();
    }
    return $txt;
}

#   parse configuration text
#
sub parsecfgtxt ($)
{
    my ($text) = @_;
    my $parse = {};
    my $osspcfg = new OSSP::cfg::simple;
    $osspcfg->parse($text) || die "error parsing config file";
    $parse = $osspcfg->unpack(-index => '.*', -strip => '.*', -flatten => 1) || die "error unpacking config file";
    return $parse;
}

#   merge configuration
#
#   merges two hashes. First argument is a hash working as accumulator and the
#   second argument is the hash to be added to it. Either argument can be
#   empty.  A typical application is the accumulator being prefilled with
#   defaults and the adder comes with overrides. The function recursively
#   processes nested hashes. Values with dissimilar keys will be merged,
#   missing data on either side will be accumulated and identical keys on both
#   sides will be overwritten with the added data. Returns a new hash with
#   cloned data. The original accumulator and adder passed in remain untouched.
#   If the first element in an array is a hash it is assumed a pseudo-hash as
#   described in perlref(1) encountered and hash merging is attempted.
#
sub mergecfg ($$) {
    my ($acc, $add) = @_;
    $acc = clone($acc);
    $add = clone($add);
    foreach my $k (sort keys %{$add}) {
        if (    (ref($acc->{$k}) eq "HASH" || (ref($acc->{$k}) eq "ARRAY" and ref($acc->{$k}[0]) eq "HASH"))
            and (ref($add->{$k}) eq "HASH" || (ref($add->{$k}) eq "ARRAY" and ref($add->{$k}[0]) eq "HASH"))
           ) {
            $acc->{$k} = &mergecfg($acc->{$k}, $add->{$k});
        }
        else {
            $acc->{$k} = $add->{$k};
        }
    }
    return $acc;
}

1;
